@@ -13,7 +13,10 @@ def _context_aware_task_factory(loop, coro):
     Custom task factory function.
     """
     task = asyncio.Task(coro, loop=loop)
+
+    # noinspection PyUnresolvedReferences,PyProtectedMember
     if task._source_traceback:
+        # noinspection PyUnresolvedReferences,PyProtectedMember
         del task._source_traceback[-1]
 
     # Propagate only the X-Ray context to the new task, if present
@@ -26,7 +29,7 @@ def _context_aware_task_factory(loop, coro):
         # Propagate a copy of the current stack of entities (segment, plus
         # ordered subsegments). We don't want to share the same entity stack
         # amongst concurrent tasks, because that's just wrong.
-        new_context = {"entities": list(current_task.context["entities"])}
+        new_context = {"entities": list(current_task.context.get("entities", []))}
         setattr(task, "context", new_context)
 
     return task
